summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorw00t <w00t@e03df62e-2008-0410-955e-edbf42e46eb7>2009-09-05 22:48:00 +0000
committerw00t <w00t@e03df62e-2008-0410-955e-edbf42e46eb7>2009-09-05 22:48:00 +0000
commitb49d529981f4336347c5f7c17d8ce656ad50b1e5 (patch)
treee286d955ed0b85b1971cbb2ff6cd421ab586f4e2 /include
parentb6decc75f28e24522bfc4a3a74dbacce22d5cb02 (diff)
Likewise, convert OnLocalTopicChange to OnPreTopicChange and to be run for both local and remote changes, for API consistency.
git-svn-id: http://svn.inspircd.org/repository/trunk/inspircd@11678 e03df62e-2008-0410-955e-edbf42e46eb7
Diffstat (limited to 'include')
-rw-r--r--include/modules.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/include/modules.h b/include/modules.h
index 4af979118..3f779fe80 100644
--- a/include/modules.h
+++ b/include/modules.h
@@ -422,7 +422,7 @@ enum Implementation
I_OnUserPostNick, I_OnAccessCheck, I_On005Numeric, I_OnKill, I_OnRemoteKill, I_OnLoadModule,
I_OnUnloadModule, I_OnBackgroundTimer, I_OnPreCommand, I_OnCheckReady, I_OnCheckInvite,
I_OnRawMode, I_OnCheckKey, I_OnCheckLimit, I_OnCheckBan, I_OnCheckExtBan, I_OnCheckStringExtBan,
- I_OnStats, I_OnChangeLocalUserHost, I_OnChangeLocalUserGecos, I_OnLocalTopicChange,
+ I_OnStats, I_OnChangeLocalUserHost, I_OnChangeLocalUserGecos, I_OnPreTopicChange,
I_OnPostTopicChange, I_OnEvent, I_OnRequest, I_OnGlobalOper, I_OnPostConnect, I_OnAddBan,
I_OnDelBan, I_OnRawSocketAccept, I_OnRawSocketClose, I_OnRawSocketWrite, I_OnRawSocketRead,
I_OnChangeLocalUserGECOS, I_OnUserRegister, I_OnChannelPreDelete, I_OnChannelDelete,
@@ -1210,17 +1210,18 @@ class CoreExport Module : public Extensible
*/
virtual ModResult OnChangeLocalUserGECOS(User* user, const std::string &newhost);
- /** Called whenever a topic is changed by a local user.
+ /** Called before a topic is changed.
* Return 1 to deny the topic change, 0 to check details on the change, -1 to let it through with no checks
+ * As with other 'pre' events, you should only ever block a local event.
* @param user The user changing the topic
* @param chan The channels who's topic is being changed
* @param topic The actual topic text
* @param 1 to block the topic change, 0 to allow
*/
- virtual ModResult OnLocalTopicChange(User* user, Channel* chan, const std::string &topic);
+ virtual ModResult OnPreTopicChange(User* user, Channel* chan, const std::string &topic);
/** Called whenever a topic has been changed.
* To block topic changes you must use OnLocalTopicChange instead.
* @param user The user changing the topic
* @param chan The channels who's topic is being changed
* @param topic The actual topic text
@@ -1210,17 +1210,18 @@ class CoreExport Module : public Extensible
/** Called whenever a topic has been changed.
- * To block topic changes you must use OnLocalTopicChange instead.
+ * To block topic changes you must use OnPreTopicChange instead.
* @param user The user changing the topic
* @param chan The channels who's topic is being changed